about summary refs log tree commit diff
path: root/sysdeps/unix/sysv/linux/bits
diff options
context:
space:
mode:
authorFlorian Weimer <fweimer@redhat.com>2019-02-02 14:13:33 +0100
committerFlorian Weimer <fweimer@redhat.com>2019-02-02 14:15:27 +0100
commitc70824b9a4645c0ecd049da8cfdb2c28ae7ada23 (patch)
treefe97a1176e0983462c79a9331cf4324f62d5d64e /sysdeps/unix/sysv/linux/bits
parent4dcbbc3b28aaeafe23e1a30db84055aa6f6fa987 (diff)
downloadglibc-c70824b9a4645c0ecd049da8cfdb2c28ae7ada23.tar.gz
glibc-c70824b9a4645c0ecd049da8cfdb2c28ae7ada23.tar.xz
glibc-c70824b9a4645c0ecd049da8cfdb2c28ae7ada23.zip
manual: Document lack of conformance of sched_* functions [BZ #14829]
On Linux, we define _POSIX_PRIORITY_SCHEDULING, but functions such
as sched_setparam and sched_setscheduler apply to individual threads,
not processes.

Reviewed-by: Carlos O'Donell <carlos@redhat.com>
Diffstat (limited to 'sysdeps/unix/sysv/linux/bits')
-rw-r--r--sysdeps/unix/sysv/linux/bits/posix_opt.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/sysdeps/unix/sysv/linux/bits/posix_opt.h b/sysdeps/unix/sysv/linux/bits/posix_opt.h
index b3bf5efd4d..ca020d3cdd 100644
--- a/sysdeps/unix/sysv/linux/bits/posix_opt.h
+++ b/sysdeps/unix/sysv/linux/bits/posix_opt.h
@@ -25,7 +25,10 @@
 /* Processes have a saved set-user-ID and a saved set-group-ID.  */
 #define	_POSIX_SAVED_IDS	1
 
-/* Priority scheduling is supported.  */
+/* Priority scheduling is not supported with the correct semantics,
+   but GNU/Linux applications expect that the corresponding interfaces
+   are available, even though the semantics do not meet the POSIX
+   requirements.  See glibc bug 14829.  */
 #define	_POSIX_PRIORITY_SCHEDULING	200809L
 
 /* Synchronizing file data is supported.  */